Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1)

Unified Diff: chrome/browser/ui/cocoa/tabs/tab_strip_controller.h

Issue 6821003: [Mac] First pass at multiple selection in the tabstrip. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase ToT Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
diff --git a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
index 9b90daff28f872558951fb20b6f329f0ac494f8b..ca5e2bae213e0bd97b52f3bcde70b964e1bf465e 100644
--- a/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
+++ b/chrome/browser/ui/cocoa/tabs/tab_strip_controller.h
@@ -41,13 +41,14 @@ class NotificationBridge;
@protocol TabStripControllerDelegate
// Stripped down version of TabStripModelObserverBridge:selectTabWithContents.
-- (void)onSelectTabWithContents:(TabContents*)contents;
+- (void)onActivateTabWithContents:(TabContents*)contents;
// Stripped down version of TabStripModelObserverBridge:tabReplacedWithContents.
- (void)onReplaceTabWithContents:(TabContents*)contents;
// Stripped down version of TabStripModelObserverBridge:tabChangedWithContents.
-- (void)onSelectedTabChange:(TabStripModelObserver::TabChangeType)change;
+- (void)onTabChanged:(TabStripModelObserver::TabChangeType)change
+ withContents:(TabContents*)contents;
// Stripped down version of TabStripModelObserverBridge:tabDetachedWithContents.
- (void)onTabDetachedWithContents:(TabContents*)contents;
@@ -170,11 +171,11 @@ class NotificationBridge;
browser:(Browser*)browser
delegate:(id<TabStripControllerDelegate>)delegate;
-// Return the view for the currently selected tab.
-- (NSView*)selectedTabView;
+// Return the view for the currently active tab.
+- (NSView*)activeTabView;
-// Set the frame of the selected tab, also updates the internal frame dict.
-- (void)setFrameOfSelectedTab:(NSRect)frame;
+// Set the frame of the active tab, also updates the internal frame dict.
+- (void)setFrameOfActiveTab:(NSRect)frame;
// Move the given tab at index |from| in this window to the location of the
// current placeholder.
« no previous file with comments | « chrome/browser/ui/cocoa/tabs/tab_controller_unittest.mm ('k') | chrome/browser/ui/cocoa/tabs/tab_strip_controller.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698